@@ -1,12 +1,10 @@
 import os
 
-from django.views.generic import ListView
-
 from djangomaster.conf import settings
-from djangomaster.views import MasterMixin
+from djangomaster.views import MasterView
 
 
-class HomeView(MasterMixin, ListView):
+class HomeView(MasterView):
     template_name = 'djangomaster/home.html'
     context_object_name = 'object'
     menu_item = 'home'
